==> pg-calendar-1.4.5.tgz: package/README.md <==
# PIGNOSE Calendar

Beautiful and eidetic jQuery date picker plugin.

[![npm version](https://badge.fury.io/js/pg-calendar.svg)](https://badge.fury.io/js/pg-calendar) [![Bower version](https://badge.fury.io/bo/pg-calendar.svg)](https://badge.fury.io/bo/pg-calendar) [![Join the chat at https://gitter.im/KennethanCeyer/PIGNOSE](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/KennethanCeyer/PIGNOSE?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

----

### Getting started

PIGNOSE-Calendar helps you make more simple and eidetic datepicker in jQuery.

The datepicker supports responsive and mobile environment.

[Check demo page](http://www.pigno.se/barn/PIGNOSE-Calendar)

![PIGNOSE-Calendar](http://www.pigno.se/barn/PIGNOSE-Calendar/demo/img/screenshot_main.png?t=201701170854)

----

### Usage

Check `dist/` folder on this repository.

1. Install from git.

 ```shell
  git clone git@github.com:KennethanCeyer/PIGNOSE-Calendar.git
```

2. Check distributed folder.

 ```shell
  cd ./PIGNOSE-Calendar/dist
  ls -al
```

3. Insert snippets at `<head>` tag of your html file.

 ```html
<script src="./dist/pignose.calendar.min.js"></script>
<link type="text/css" href="./dist/pignose.calendar.min.css" />
```

----

### Overview

See our features which we are supported.

- Responsive and mobile friendly display.
- Multiple range datepicker support.
- Input type controller support.
- The toggle controll each of date buttons are supported.
- You can disable specific dates.
- Multiple languages are supported, (en, ko, fr, ch, de, jp, pt, da, pl, es).
- Theme system supports (light, dark, blue).

----

### Contributors

We welcome your support, You can support to notice by send me github issue or using gitter.

#### Languages

- [@adrian2monk](https://www.github.com/adrian2monk)
- [@feldmarv](https://www.github.com/feldmarv)
- [@matheusdelima](https://www.github.com/matheusdelima)
- [@maxma51](https://www.github.com/maxma51)
- [@pkly](https://www.github.com/pkly)
- [@TNDecoder](https://www.github.com/TNDecoder)

----

### Question

If you found something problem of this plugin, or you have some question.

Please send me a message to use either [gitter](https://gitter.im/KennethanCeyer/PIGNOSE) or [Github issue](https://github.com/KennethanCeyer/PIGNOSE-Calendar/issues). (gitter url is on the top of the manual)

==> pg-calendar-1.4.9.tgz: package/README.md <==
# PIGNOSE Calendar

Beautiful and eidetic jQuery date picker plugin.

[![npm version](https://badge.fury.io/js/pg-calendar.svg)](https://badge.fury.io/js/pg-calendar) [![Bower version](https://badge.fury.io/bo/pg-calendar.svg)](https://badge.fury.io/bo/pg-calendar) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Join the chat at https://gitter.im/KennethanCeyer/PIGNOSE](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/KennethanCeyer/PIGNOSE?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

----

### Getting started

PIGNOSE-Calendar helps you make more simple and eidetic datepicker in jQuery.

The datepicker supports responsive and mobile environment.

[Check demo page](http://www.pigno.se/barn/PIGNOSE-Calendar)

![PIGNOSE-Calendar](http://www.pigno.se/barn/PIGNOSE-Calendar/demo/img/screenshot_main.png?t=201701170854)

----

### Usage

Check `dist/` folder on this repository.

1. Install from git.

 ```bash
  $ git clone git@github.com:KennethanCeyer/PIGNOSE-Calendar.git
```

2. Check distributed folder.

 ```bash
  $ cd ./PIGNOSE-Calendar/dist
  $ ls -al
```

3. Insert snippets at `<head>` tag of your html file.

 ```html
<script src="./dist/pignose.calendar.min.js"></script>
<link type="text/css" href="./dist/pignose.calendar.min.css" />
```

----

### Overview

See our features which we are supported.

- Responsive and mobile friendly display.
- Multiple range datepicker support.
- Scheduling calendar support.
- Input type controller support.
- The toggle controll each of date buttons are supported.
- You can disable specific dates.
- Multiple languages are supported, (en, ko, fr, ch, de, jp, pt, da, pl, es).
- Theme system supports (light, dark, blue).

----

### Contributors

We welcome your support, You can support to notice by send me github issue or using gitter.

#### Languages

- [@adrian2monk](https://www.github.com/adrian2monk)
- [@feldmarv](https://www.github.com/feldmarv)
- [@matheusdelima](https://www.github.com/matheusdelima)
- [@maxma51](https://www.github.com/maxma51)
- [@pkly](https://www.github.com/pkly)
- [@TNDecoder](https://www.github.com/TNDecoder)

----

### Question

If you found something problem of this plugin, or you have some question.

Please send me a message to use either [gitter](https://gitter.im/KennethanCeyer/PIGNOSE) or [Github issue](https://github.com/KennethanCeyer/PIGNOSE-Calendar/issues). (gitter url is on the top of the manual)
